@@ -11,5 +11,5 @@ class AvatarImageProvider : public QQuickImageProvider
 public:
     explicit AvatarImageProvider();
 
-    QImage requestImage(const QString &number, QSize *size, const QSize &requestedSize) override;
+    QPixmap requestPixmap(const QString &number, QSize *size, const QSize &requestedSize) override;
 };
