@@ -24,8 +24,12 @@ public:
     void showPassiveNotification(const QString &message, int timeout = 0);
     void showPassiveNotification(const QString &message, PassiveNotificationDuation timeout);
 
-    Q_INVOKABLE bool isPhoneNumber(const QString &text);
+    Q_INVOKABLE bool isPhoneNumber(const QString &text) const;
+    Q_INVOKABLE bool isPremiumNumber(const QString &text) const;
     Q_INVOKABLE static void launchPhonebook();
+    Q_INVOKABLE void copyTextToClipboard(const QString &text) const;
+
+    static QString textToHtml(const QString &text);
 
     static Utils *instance();
 
@@ -36,5 +40,4 @@ public:
 private:
     QQmlApplicationEngine *m_engine;
     QQuickWindow *m_window = nullptr;
-    QRegularExpression m_phoneNumberRegex;
 };
